Skip to contents

Same latent genotype, Z, with independent errors for true donor (D) and suspect (S).

Usage

sample_data_Hp_wTwR(n, wT, wR, p, ...)

Arguments

n

number of samples

wT

error probability for donor sample

wR

error probability for PoI sample

p

list of genotype probabilities (length is number of loci) or vector of length 3 for single locus

...

Passed on to add_errors_to_genotypes()

Value

list of two matrices, each of size n x loci with genotype in 0/1/2 format resembling the situation in real life.

Examples

sample_data_Hp_wTwR(n = 10, wT = 0.3, wR = 1e-6, p = c(0.25, 0.25, 0.5))
#> $xT
#>       [,1]
#>  [1,]    1
#>  [2,]    1
#>  [3,]    2
#>  [4,]    1
#>  [5,]    1
#>  [6,]    1
#>  [7,]    2
#>  [8,]    2
#>  [9,]    1
#> [10,]    1
#> 
#> $xR
#>       [,1]
#>  [1,]    2
#>  [2,]    2
#>  [3,]    1
#>  [4,]    1
#>  [5,]    1
#>  [6,]    2
#>  [7,]    2
#>  [8,]    2
#>  [9,]    2
#> [10,]    1
#> 
sample_data_Hp_wTwR(n = 10, wT = 0.3, wR = 1e-6, p = list(
  c(0.25, 0.25, 0.5), c(0.1, 0.8, 0.1)))
#> $xT
#>       [,1] [,2]
#>  [1,]    2    1
#>  [2,]    2    0
#>  [3,]    2    0
#>  [4,]    1    1
#>  [5,]    2    1
#>  [6,]    1    0
#>  [7,]    0    1
#>  [8,]    2    0
#>  [9,]    1    1
#> [10,]    0    1
#> 
#> $xR
#>       [,1] [,2]
#>  [1,]    2    1
#>  [2,]    2    0
#>  [3,]    2    1
#>  [4,]    0    1
#>  [5,]    0    1
#>  [6,]    2    1
#>  [7,]    0    1
#>  [8,]    2    1
#>  [9,]    1    1
#> [10,]    0    1
#> 
  
cases <- sample_data_Hp_wTwR(n = 1000, wT = 0, wR = 0, p = c(0.25, 0.25, 0.5))
table(xT = cases$xT, xR = cases$xR)
#>    xR
#> xT    0   1   2
#>   0 256   0   0
#>   1   0 250   0
#>   2   0   0 494
cases <- sample_data_Hp_wTwR(n = 1000, wT = 0.1, wR = 0, p = c(0.25, 0.25, 0.5))
table(xT = cases$xT, xR = cases$xR)
#>    xR
#> xT    0   1   2
#>   0 200  21   4
#>   1  45 199 102
#>   2   0  21 408
cases <- sample_data_Hp_wTwR(n = 1000, wT = 0, wR = 0.1, p = c(0.25, 0.25, 0.5))
table(xT = cases$xT, xR = cases$xR)
#>    xR
#> xT    0   1   2
#>   0 181  39   1
#>   1  25 207  22
#>   2   3 111 411
  
cases <- sample_data_Hp_wTwR(n = 1000, wT = 1e-1, wR = 1e-8, p = c(0.25, 0.25, 0.5))
tab <- table(xT = cases$xT, xR = cases$xR)
tab
#>    xR
#> xT    0   1   2
#>   0 202  31   2
#>   1  37 184  90
#>   2   2  17 435
estimate_w(tab)
#> [1] 0.0506202

cases <- sample_data_Hp_wTwR(n = 1000, wT = 0, wR = 0, p = c(0.1, 0.7, 0.2))
tab <- table(xT = cases$xT, xR = cases$xR)
diag(tab/sum(tab))
#>     0     1     2 
#> 0.095 0.727 0.178